@@ -99,6 +99,7 @@ import aws_cdk.aws_kinesisfirehose
 import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
 import aws_cdk.aws_s3
+import aws_cdk.aws_sns
 import aws_cdk.aws_sqs
 
 
@@ -222,16 +223,20 @@ class BuildDynamoDBTableProps:
     name_mapping={"encryption_key_props": "encryptionKeyProps"},
 )
 class BuildEncryptionKeyProps:
-    def __init__(self, *, encryption_key_props: typing.Any = None) -> None:
+    def __init__(
+        self, *, encryption_key_props: typing.Optional[aws_cdk.aws_kms.KeyProps] = None
+    ) -> None:
         """
         :param encryption_key_props: Optional user-provided props to override the default props for the encryption key. Default: - Default props are used.
         """
+        if isinstance(encryption_key_props, dict):
+            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
         self._values = {}
         if encryption_key_props is not None:
             self._values["encryption_key_props"] = encryption_key_props
 
     @builtins.property
-    def encryption_key_props(self) -> typing.Any:
+    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
         """Optional user-provided props to override the default props for the encryption key.
 
         default
@@ -547,13 +552,15 @@ class BuildTopicProps:
         *,
         enable_encryption: typing.Optional[bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        topic_props: typing.Any = None,
+        topic_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
     ) -> None:
         """
         :param enable_encryption: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - true (encryption enabled, managed by this CDK app).
         :param encryption_key: An optional, imported encryption key to encrypt the SNS topic with. Default: - not specified.
         :param topic_props: Optional user provided props to override the default props for the SNS topic. Default: - Default props are used.
         """
+        if isinstance(topic_props, dict):
+            topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
         self._values = {}
         if enable_encryption is not None:
             self._values["enable_encryption"] = enable_encryption
@@ -584,7 +591,7 @@ class BuildTopicProps:
         return self._values.get("encryption_key")
 
     @builtins.property
-    def topic_props(self) -> typing.Any:
+    def topic_props(self) -> typing.Optional[aws_cdk.aws_sns.TopicProps]:
         """Optional user provided props to override the default props for the SNS topic.
 
         default
